/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.Collections.Generic;

namespace OpenServers.Net.Common.FileSystem {
    /// <summary>
    /// Represents a directory in a <see cref="IFileSystem"/>.
    /// </summary>
    public interface IDirectory : IFileSystemObject {
        /// <summary>
        /// Gets the subitems (files and directories).
        /// </summary>
        IList<IFileSystemObject> GetItems();

        /// <summary>
        /// The list of directories only.
        /// </summary>
        IList<IDirectory> GetDirectories();

        /// <summary>
        /// Creates the directory.
        /// </summary>
        void Create();

        /// <summary>
        /// Creates a file, in the directory.
        /// </summary>
        IFile CreateFile(string name);

        /// <summary>
        /// Creates a sub directory.
        /// </summary>
        IDirectory CreateDirectory(string name);

        /// <summary>
        /// Gets an object from the directory.
        /// </summary>
        /// <param name="path">The path is seperated by '/'</param>
        IFileSystemObject GetObject(string path);
    }
}
