/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

namespace OpenServers.Net.Common.FileSystem {

    /// <summary>
    /// interface for a file system.
    /// </summary>
    public interface IFileSystem {
        /// <summary>
        /// Gets a file from the file system.
        /// </summary>
        /// <param name="fileName">full path of the file seperated by '/'</param>
        IFile GetFile(string fileName);

        /// <summary>
        /// Gets a directory from the file system.
        /// </summary>
        /// <param name="path">full path seperated by '/'</param>
        IDirectory GetDirectory(string path);

        /// <summary>
        /// Gets an object from the file system.
        /// </summary>
        /// <param name="path">full path seperated by '/'</param>
        IFileSystemObject GetObject(string path);

        /// <summary>
        /// The root directory of the file system.
        /// </summary>
        IDirectory RootDirectory { get; }
    }
}
