/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.IO;

namespace OpenServers.Net.Common.FileSystem.Virtual {
    /// <summary>
    /// a virtual file which was newly created.
    /// </summary>
    public abstract class NewVirtualFile : VirtualFile {
        /// <summary>
        /// constructor.
        /// </summary>
        public NewVirtualFile(IDirectory parent, string name)
            : base(parent, name) {
            Exists = false;
        }

        /// <summary>
        /// open an output stream.
        /// </summary>
        public override Stream OpenOutputStream() {
            return new NotifyMeWhenYourDoneStream(this);
        }

        /// <summary>
        /// called when the stream has been closed.
        /// </summary>
        protected virtual void StreamClosed(MemoryStream stream) {

        }

        private class NotifyMeWhenYourDoneStream : MemoryStream {
            private readonly NewVirtualFile _owner;

            public NotifyMeWhenYourDoneStream(NewVirtualFile owner) {
                _owner = owner;
            }

            public override void Close() {
                base.Close();
                _owner.StreamClosed(this);
            }
        }

    }
}
