/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.IO;
using OpenServers.Net.Common.Socket;
using OpenServers.Net.Common.State;

namespace OpenServers.Net.Common.Listener {
    /// <summary>
    /// interface for defining a listener.
    /// </summary>
    public interface IListener {
        /// <summary>
        /// Starts the listener.
        /// </summary>
        void Start(IServer server);

        /// <summary>
        /// Stops the listener.
        /// </summary>
        void Stop();

        /// <summary>
        /// Sends data to client.
        /// </summary>
        void Send(IState state, string data);

        /// <summary>
        /// sends a stream of data to the client.
        /// </summary>
        void Send(IState state, Stream stream);

        /// <summary>
        /// creates a socket.
        /// </summary>
        ISocket CreateSocket();

        /// <summary>
        /// Checks if the listener is started.
        /// </summary>
        bool Started { get; }
    }
}
