/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using OpenServers.Net.Common.FileSystem;
using OpenServers.Net.Common.User;

namespace OpenServers.Net.Common.Security {
    /// <summary>
    /// interface for a security provider to lock down <see cref="IFileSystemObject"/>s.
    /// </summary>
    public interface ISecurityProvider {
        /// <summary>
        /// validates a user in the system.
        /// </summary>
        IUser ValidateUser(string userName, string password);

        /// <summary>
        /// function to determine if you can write to an object.
        /// </summary>
        bool CanWrite(IUser user, IFileSystemObject fileSystemObject);

        /// <summary>
        /// function to determine if you can read an object.
        /// </summary>
        bool CanRead(IUser user, IFileSystemObject fileSystemObject);
    }
}
