/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using NMock2;
using NUnit.Framework;

namespace OpenServers.Net.Common.FileSystem {
    [TestFixture]
    public class AbstractFileSystemTest : BaseNMockTest {
        private IDirectory _rootDir;
        private MockAbstractFileSystem _abstractFileSystem;
        private IFile _file;
        private IDirectory _dir;

        [SetUp]
        public override void SetUp() {
            base.SetUp();
            _rootDir = Mocks.NewMock<IDirectory>();
            _file = Mocks.NewMock<IFile>();
            _dir = Mocks.NewMock<IDirectory>();
            _abstractFileSystem = new MockAbstractFileSystem(_rootDir);
        }

        [Test]
        public void TestGetFile() {
            Expect.Once.On(_rootDir).Method("GetObject").With("/a.txt").Will(Return.Value(_file));

            IFile result = _abstractFileSystem.GetFile("/a.txt");
            Assert.IsNotNull(result);
        }

        [Test]
        public void TestGetFileDoesNotExist() {
            Expect.Once.On(_rootDir).Method("GetObject").With("/a.txt").Will(Return.Value(null));

            IFile result = _abstractFileSystem.GetFile("/a.txt");
            Assert.IsNull(result);
        }

        [Test]
        public void TestGetDirectory() {
            Expect.Once.On(_rootDir).Method("GetObject").With("/a/").Will(Return.Value(_dir));

            IDirectory result = _abstractFileSystem.GetDirectory("/a/");
            Assert.IsNotNull(result);
        }

        [Test]
        public void TestGetDirectoryDoesNotExist() {
            Expect.Once.On(_rootDir).Method("GetObject").With("/a/").Will(Return.Value(null));

            IDirectory result = _abstractFileSystem.GetDirectory("/a/");
            Assert.IsNull(result);
        }

        private class MockAbstractFileSystem : AbstractFileSystem {
            public MockAbstractFileSystem(IDirectory rootDir)
                : base(rootDir) {
            }
        }
    }
}
