/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.IO;
using NUnit.Framework;
using OpenServers.Net.Common.FileSystem.Disk;

namespace OpenServers.Net.Common.FileSystem {
    [TestFixture]
    public class DiskFileSystemTest {
        private DiskFileSystem _diskFileSystem;
        private string _tempPath;

        [SetUp]
        public void SetUp() {
            _tempPath = Path.GetTempPath() + "\\DiskFileSystemTest";
            Directory.CreateDirectory(_tempPath);
            _diskFileSystem = new DiskFileSystem(_tempPath);
        }

        [TearDown]
        public void TearDown() {
            Directory.Delete(_tempPath, true);
        }

        [Test]
        public void TestGetFileLeadingSlash() {
            DiskFile file = (DiskFile)_diskFileSystem.GetFile("/a.txt");
            Assert.IsNotNull(file);
            Assert.AreEqual(false, file.Exists);
            Assert.AreEqual("a.txt", file.Name);
        }

        [Test]
        public void TestGetObject() {
            DiskFile file = (DiskFile)_diskFileSystem.GetObject("/a/b/a.txt");
            Assert.IsNotNull(file);
            Assert.AreEqual(false, file.Exists);
            Assert.AreEqual("/a/b/a.txt", file.FullPath);
        }

        [Test]
        public void TestGetFile() {
            DiskFile file = (DiskFile)_diskFileSystem.GetFile("a.txt");
            Assert.IsNotNull(file);
            Assert.AreEqual(false, file.Exists);
            Assert.AreEqual("a.txt", file.Name);
        }

        [Test]
        public void TestGetDirectoryLeadingSlash() {
            DiskDirectory directory = (DiskDirectory)_diskFileSystem.GetDirectory("/test/");
            Assert.IsNotNull(directory);
            Assert.AreEqual(false, directory.Exists);
            Assert.AreEqual("test", directory.Name);
        }

        [Test]
        public void TestGetDirectory() {
            DiskDirectory directory = (DiskDirectory)_diskFileSystem.GetDirectory("test/");
            Assert.IsNotNull(directory);
            Assert.AreEqual(false, directory.Exists);
            Assert.AreEqual("test", directory.Name);
        }
    }
}
