/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.IO;
using NUnit.Framework;

namespace OpenServers.Net.Common.FileSystem.Virtual {
    [TestFixture]
    public class NewVirtualFileTest {
        [Test]
        public void TestOpenOutputStream() {
            MockNewVirtualFile nvf = new MockNewVirtualFile(null, "a");
            Stream output = nvf.OpenOutputStream();
            byte[] buffer = new byte[] { 1, 2, 3 };
            output.Write(buffer, 0, buffer.Length);
            output.Close();
            Assert.AreEqual(buffer, nvf.Data);
        }

        private class MockNewVirtualFile : NewVirtualFile {
            private byte[] _data;

            public MockNewVirtualFile(IDirectory parent, string name)
                : base(parent, name) {
            }

            public byte[] Data {
                get { return _data; }
            }

            protected override void StreamClosed(MemoryStream stream) {
                _data = stream.ToArray();
                base.StreamClosed(stream);
            }
        }
    }
}
