/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.Collections.Generic;
using NUnit.Framework;

namespace OpenServers.Net.Common.FileSystem.Virtual {
    [TestFixture]
    public class VirtualDirectoryTest {
        private VirtualDirectory _virtualDirectory;
        private VirtualDirectory _virtualDirectoryParent;

        [SetUp]
        public void SetUp() {
            _virtualDirectoryParent = new VirtualDirectory(null, "test");
            _virtualDirectory = new VirtualDirectory(_virtualDirectoryParent, "test");
            _virtualDirectoryParent.GetItems().Add(_virtualDirectory);
        }

        [Test]
        public void TestGetObject() {
            IFileSystemObject dir = _virtualDirectoryParent.GetObject("/test/");
            Assert.AreEqual(_virtualDirectory, dir);
        }

        [Test]
        public void TestFullPath() {
            string fullPath = _virtualDirectory.FullPath;
            Assert.AreEqual("/test/", fullPath);
        }

        [Test]
        public void TestCreateDirectory() {
            Assert.IsNull(_virtualDirectory.CreateDirectory("a"));
        }

        [Test]
        public void TestCreateFile() {
            Assert.IsNull(_virtualDirectory.CreateFile("a"));
        }

        [Test]
        public void TestGetItems() {
            IList<IFileSystemObject> children = _virtualDirectoryParent.GetItems();
            Assert.AreEqual(1, children.Count);
        }

        [Test]
        public void TestGetDirectories() {
            IList<IDirectory> children = _virtualDirectoryParent.GetDirectories();
            Assert.AreEqual(1, children.Count);
        }

        [Test]
        public void TestCreate() {
            _virtualDirectory.Create();
            Assert.IsTrue(_virtualDirectory.Exists);
            Assert.IsTrue(_virtualDirectoryParent.Exists);
        }
    }
}
