/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;
using NMock2;
using NUnit.Framework;
using OpenServers.Net.Common.FileSystem;
using OpenServers.Net.Common.User;

namespace OpenServers.Net.Common.Security {
    [TestFixture]
    public class AbstractSecurityProviderTest : BaseNMockTest {
        private AbstractSecurityProvider _securityProvider;
        private IUser _user;
        private IFileSystemObject _fso;

        [SetUp]
        public override void SetUp() {
            base.SetUp();

            _user = Mocks.NewMock<IUser>();
            _fso = Mocks.NewMock<IFileSystemObject>();
            _securityProvider = new MySecurityProvider();
        }

        [Test]
        public void TestCanWriteReadOnly() {
            Expect.Once.On(_fso).GetProperty("ReadOnly").Will(Return.Value(true));

            bool results = _securityProvider.CanWrite(_user, _fso);
            Assert.IsFalse(results);
        }

        [Test]
        public void TestCanWriteNotReadOnly() {
            Expect.Once.On(_fso).GetProperty("ReadOnly").Will(Return.Value(false));

            bool results = _securityProvider.CanWrite(_user, _fso);
            Assert.IsTrue(results);
        }

        [Test]
        public void TestCanRead() {
            bool results = _securityProvider.CanRead(_user, _fso);
            Assert.IsTrue(results);
        }

        public class MySecurityProvider : AbstractSecurityProvider {
            public override IUser ValidateUser(string userName, string password) {
                throw new NotImplementedException();
            }
        }
    }
}
