/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using NUnit.Framework;
using System.Windows.Forms;

namespace OpenServers.Net.Common.Security {
    [TestFixture]
    public class NtAuthSecurityProviderTest {
        private NtAuthSecurityProvider _securityProvider;

        [SetUp]
        public void SetUp() {
            _securityProvider = new NtAuthSecurityProvider();
        }

        [Test]
        public void TestValidateUser() {
            NtAuthSecurityProvider.NtUser user = (NtAuthSecurityProvider.NtUser)_securityProvider.ValidateUser("red", "red");
            Assert.IsNotNull(user);
            Assert.AreEqual("red", user.UserName);
            Assert.IsNotNull(user.Token);
            Assert.IsNull(user.Domain);
        }

        [Test]
        public void TestValidateUserWithDomain() {
            string computerName = SystemInformation.ComputerName;

            NtAuthSecurityProvider.NtUser user = (NtAuthSecurityProvider.NtUser)_securityProvider.ValidateUser(computerName + "\\red", "red");
            Assert.IsNotNull(user);
            Assert.AreEqual("red", user.UserName);
            Assert.IsNotNull(user.Token);
            Assert.AreEqual(computerName, user.Domain);
        }

        [Test]
        public void TestValidateUserBadPassword() {
            NtAuthSecurityProvider.NtUser user = (NtAuthSecurityProvider.NtUser)_securityProvider.ValidateUser("red", "badpassword");
            Assert.IsNull(user);
        }

        [Test]
        public void TestValidateUserBadUser() {
            NtAuthSecurityProvider.NtUser user = (NtAuthSecurityProvider.NtUser)_securityProvider.ValidateUser("baduser", "red");
            Assert.IsNull(user);
        }
    }
}
