/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;
using NUnit.Framework;

namespace OpenServers.Net.Common.Utils {
    [TestFixture]
    public class ArrayUtilsTest {
        [Test]
        public void TestToStringNull() {
            string results = ArrayUtils.Join((object[])null);
            Assert.AreEqual("null", results);
        }

        [Test]
        public void TestToStringObjectLength0() {
            string results = ArrayUtils.Join(new object[] { });
            Assert.AreEqual("", results);
        }

        [Test]
        public void TestToStringObjectLength1() {
            string results = ArrayUtils.Join(new object[] { "a" });
            Assert.AreEqual("a", results);
        }

        [Test]
        public void TestToString() {
            string results = ArrayUtils.Join(new object[] { "a", "b" });
            Assert.AreEqual("a, b", results);
        }


        [Test]
        public void TestToStringWithNullObject() {
            string results = ArrayUtils.Join(new object[] { "a", null });
            Assert.AreEqual("a, null", results);
        }

        [Test]
        public void TestJoinMultipleVariusObjects() {
            string ret = ArrayUtils.Join(new object[] { 1, "b", null });
            Assert.AreEqual("1, b, null", ret);
        }

        [Test]
        public void TestJoinMultiplePrimitiveObjects() {
            string ret = ArrayUtils.Join(new int[] { 1, 2, 3 });
            Assert.AreEqual("1, 2, 3", ret);
        }

        [Test]
        public void TestCompareNotEqual() {
            Assert.IsFalse(ArrayUtils.Compare(new byte[] { 0, 1, 2 }, new byte[] { 1, 2, 3 }, 3));
        }

        [Test]
        public void TestCompareWrongLength() {
            try {
                ArrayUtils.Compare(new byte[] { 0, 1, 2 }, new byte[] { 1, 2, 3 }, 5);
                Assert.Fail("should throw error");
            } catch (ArgumentException) {
                //ok
            }
        }
    }
}
