/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;
using NUnit.Framework;

namespace OpenServers.Net.Common.Utils {
    [TestFixture]
    public class PrivateObjectTest {
        private MyObject _myObject;
        private PrivateObject<MyObject> _privateObject;

        [SetUp]
        public void SetUp() {
            _myObject = new MyObject();
            _privateObject = new PrivateObject<MyObject>(_myObject);
        }

        [Test]
        public void TestExecuteMethod() {
            _privateObject.ExecuteMethod("Method1", "a", "b");
        }

        [Test]
        [ExpectedException(ExceptionType = typeof(ArgumentNullException))]
        public void TestExecuteMethodBadParameters() {
            _privateObject.ExecuteMethod("Method1", new object[] { null });
        }

        [Test]
        public void TestExecuteMethodMethodNotFound() {
            try {
                _privateObject.ExecuteMethod("MethodNotFound", "a", "b");
                Assert.Fail("Should fail with method access exception");
            } catch (MethodAccessException) {
            }
        }

#pragma warning disable 168
        public class MyObject {
            protected void Method1(string a, string b) {

            }
        }
#pragma warning restore 168
    }
}
