/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using NUnit.Framework;

namespace OpenServers.Net.Common.Utils {
    [TestFixture]
    public class UrlTest {
        [Test]
        public void TestNewUrl() {
            Url url = new Url("/test.html?a=1&b=2#ttt");
            Assert.AreEqual("/test.html", url.Path);
            Assert.AreEqual("ttt", url.Anchor);
            Assert.AreEqual("/test.html?a=1&b=2#ttt", url.ToString());
        }

        [Test]
        public void TestNewUrlParameterWithoutValue() {
            Url url = new Url("/test.html?a=1&b");
            Assert.AreEqual("/test.html?a=1&b=", url.ToString());
        }

        [Test]
        public void TestNewUrlParameterMultipleNames() {
            Url url = new Url("/test.html?a=1&a=2");
            Assert.AreEqual("/test.html?a=1&a=2", url.ToString());
        }

        [Test]
        public void TestAddParameter() {
            Url url = new Url("/test.html");
            url.AddParameter("a", "val");
            Assert.AreEqual("/test.html?a=val", url.ToString());
        }

        [Test]
        public void TestSetPath() {
            Url url = new Url("/test.html");
            url.Path = "/blah.html";
            Assert.AreEqual("/blah.html", url.ToString());
        }
    }
}
