/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.Collections.Generic;
using System.Text;
using OpenServers.Net.FtpServer.State;

namespace OpenServers.Net.FtpServer.Command {
    /// <summary>
    ///     <para>
    ///         <b>FEATURE (FEAT)</b><br/>
    ///     </para>
    ///     <para>
    ///         <b>Format</b><br/>
    ///         <code>FEAT &lt;CRLF&gt;</code>
    ///     </para>
    /// </summary>
    public class FeatureCommand : BaseCommand {
        /// <summary>
        /// Returns a list of features that are supported by the server.
        /// </summary>
        public override void PerformCommand(IFtpServer server, FtpState state, string arguments) {
            IList<KeyValuePair<string, FtpServer.CommandContainer>> featureCommands = new List<KeyValuePair<string, FtpServer.CommandContainer>>();
            foreach (KeyValuePair<string, FtpServer.CommandContainer> commandPair in server.CommandMap) {
                if (commandPair.Value.CommandType.IsAssignableFrom(typeof(IFeatureCommand))) {
                    featureCommands.Add(commandPair);
                }
            }

            if (featureCommands.Count == 0) {
                state.Listener.Send(state, server.Messages.Get211(Reason211.NoFeatures));
            } else {
                StringBuilder sb = new StringBuilder();
                sb.Append(server.Messages.Get211(Reason211.ExtensionsSupported));
                foreach (KeyValuePair<string, FtpServer.CommandContainer> featureCommand in featureCommands) {
                    IFeatureCommand command = (IFeatureCommand)featureCommand.Value.CommandConstructor.Invoke(new object[] { });
                    string featureParams = command.FeatureParams;
                    if (featureParams == null || featureParams.Length == 0) {
                        sb.Append(string.Format(" {0}", featureCommand.Key));
                    } else {
                        sb.Append(string.Format(" {0} {1}", featureCommand.Key, featureParams));
                    }
                }
                sb.Append(server.Messages.Get211(Reason211.End));
                state.Listener.Send(state, sb.ToString());
            }
        }
    }
}
