/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using OpenServers.Net.FtpServer.State;

namespace OpenServers.Net.FtpServer.Command {
    /// <summary>
    ///     <para>
    ///         <b>SYSTEM (SYST)</b><br/>
    ///         This command is used to find out the type of operating
    ///         system at the server.  The reply shall have as its first
    ///         word one of the system names listed in the current version
    ///         of the Assigned Numbers document [4].
    ///     </para>
    ///     <para>
    ///         <b>Format</b><br/>
    ///         <code>SYST &lt;CRLF&gt;</code>
    ///     </para>
    ///     <para>
    ///         <b>Success:</b>
    ///         <list type="bullet">
    ///             <item><term>215</term><description>NAME system type. Where NAME is an official system name from the list in the Assigned Numbers document.</description></item>
    ///         </list>
    ///     </para>
    ///     <para>
    ///         <b>Errors:</b>
    ///         <list type="bullet">
    ///             <item><term>500</term><description>Syntax error, command unrecognized.</description></item>
    ///             <item><term>501</term><description>Syntax error in parameters or arguments.</description></item>
    ///             <item><term>502</term><description>Command not implemented.</description></item>
    ///             <item><term>421</term><description>Service not available, closing control connection.</description></item>
    ///         </list>
    ///     </para>
    /// </summary>
    public class SystemCommand : BaseCommand {
        /// <summary>
        /// returns the servers system.
        /// </summary>
        public override void PerformCommand(IFtpServer server, FtpState state, string arguments) {
            if (!string.IsNullOrEmpty(arguments)) {
                state.Listener.Send(state, server.Messages.Get501());
            } else {
                string data = server.Messages.Get215(server.SystemTypeString);
                state.Listener.Send(state, data);
            }
        }
    }
}
