/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System.Collections.Generic;
using OpenServers.Net.Common;
using OpenServers.Net.Common.FileSystem;
using OpenServers.Net.Common.Security;
using OpenServers.Net.FtpServer.Command;

namespace OpenServers.Net.FtpServer {
    /// <summary>
    /// interface for the FTP server.
    /// </summary>
    public interface IFtpServer : IServer {
        /// <summary>
        /// The backing file system.
        /// </summary>
        IFileSystem FileSystem { get; }

        /// <summary>
        /// the messages provider.
        /// </summary>
        IMessages Messages { get; }

        /// <summary>
        /// The security provider.
        /// </summary>
        ISecurityProvider SecurityProvider { get; }

        /// <summary>
        /// A map of all the valid FTP commands.
        /// </summary>
        IDictionary<string, FtpServer.CommandContainer> CommandMap { get; }

        /// <summary>
        /// The system type string <see cref="SystemCommand"/>
        /// </summary>
        string SystemTypeString { get; }
    }
}
