/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using NMock2;
using NUnit.Framework;
using OpenServers.Net.Common.FileSystem;

namespace OpenServers.Net.FtpServer.Command {
    [TestFixture]
    public class DeleteCommandTest : AbstractCommandTest<DeleteCommand> {
        [Test]
        public void TestInvoke() {
            IFile file = Mocks.NewMock<IFile>();
            Expect.AtLeastOnce.On(file).GetProperty("Parent").Will(Return.Value(Mocks.NewMock<IDirectory>()));
            Expect.Once.On(MockFileSystem).Method("GetFile").With("/a.txt").Will(Return.Value(file));
            Expect.Once.On(file).GetProperty("Exists").Will(Return.Value(true));
            Expect.Once.On(file).Method("Delete");
            Expect.Once.On(MockSecurityProvider).Method("CanWrite").With(MockUser, file.Parent).Will(Return.Value(true));
            Expect.Once.On(MockMessages).Method("Get250");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");

            Assert.AreEqual("/", State.CurrentDirectory);
        }

        [Test]
        public void TestInvokeFileNotFound() {
            IFile file = Mocks.NewMock<IFile>();
            Expect.Once.On(MockFileSystem).Method("GetFile").With("/a.txt").Will(Return.Value(file));
            Expect.Once.On(file).GetProperty("Exists").Will(Return.Value(false));
            Expect.Once.On(MockMessages).Method("Get550").With(Reason550.FileNotFound);

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");

            Assert.AreEqual("/", State.CurrentDirectory);
        }

        [Test]
        public void TestInvokeBadAccess() {
            IFile file = Mocks.NewMock<IFile>();
            Expect.AtLeastOnce.On(file).GetProperty("Parent").Will(Return.Value(Mocks.NewMock<IDirectory>()));
            Expect.Once.On(MockFileSystem).Method("GetFile").With("/a.txt").Will(Return.Value(file));
            Expect.Once.On(file).GetProperty("Exists").Will(Return.Value(true));
            Expect.Once.On(MockSecurityProvider).Method("CanWrite").With(MockUser, file.Parent).Will(Return.Value(false));
            Expect.Once.On(MockMessages).Method("Get550").With(Reason550.AccessDenied);

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");

            Assert.AreEqual("/", State.CurrentDirectory);
        }

        [Test]
        public void TestInvokeNotLoggedIn() {
            State.User = null;
            Expect.Once.On(MockMessages).Method("Get530");
            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "/");
        }

        [Test]
        public void TestInvokeBadArgument() {
            Expect.Once.On(MockMessages).Method("Get501");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "");

            Assert.AreEqual("/", State.CurrentDirectory);
        }
    }
}
