/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using NMock2;
using NUnit.Framework;

namespace OpenServers.Net.FtpServer.Command {
    [TestFixture]
    public class PasswordCommandTest : AbstractCommandTest<PasswordCommand> {
        [SetUp]
        public override void SetUp() {
            base.SetUp();

            State.User = null;
            State.UserName = "user1";
        }

        [Test]
        public void TestInvoke() {
            Expect.Once.On(MockSecurityProvider).Method("ValidateUser").With("user1", "pass").Will(Return.Value(MockUser));
            Expect.Once.On(MockMessages).Method("Get230");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "pass");

            Assert.AreEqual(MockUser, State.User);
        }

        [Test]
        public void TestInvokeBadPassword() {
            Expect.Once.On(MockSecurityProvider).Method("ValidateUser").With("user1", "pass").Will(Return.Value(null));
            Expect.Once.On(MockMessages).Method("Get530");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "pass");

            Assert.AreEqual(null, State.User);
        }

        [Test]
        public void TestInvokeBadParam() {
            Expect.Once.On(MockMessages).Method("Get501");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "");

            Assert.AreEqual(null, State.User);
        }
    }
}
