/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using NMock2;
using NUnit.Framework;
using OpenServers.Net.Common.FileSystem;

namespace OpenServers.Net.FtpServer.Command {
    [TestFixture]
    public class StoreCommandTest : AbstractCommandTest<StoreCommand> {
        [Test]
        public void TestInvokeFileNull() {
            Expect.Once.On(MockFileSystem).Method("GetFile").With("/a.txt").Will(Return.Value(null));
            Expect.Once.On(MockMessages).Method("Get550").With(Reason550.FileNotFound);

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");
        }

        [Test]
        public void TestInvokeAccessDenied() {
            IFile file = Mocks.NewMock<IFile>();
            IDirectory fileParent = Mocks.NewMock<IDirectory>();
            Expect.Once.On(file).GetProperty("Parent").Will(Return.Value(fileParent));
            Expect.Once.On(MockFileSystem).Method("GetFile").With("/a.txt").Will(Return.Value(file));
            Expect.Once.On(MockSecurityProvider).Method("CanWrite").With(MockUser, fileParent).Will(Return.Value(false));
            Expect.Once.On(MockMessages).Method("Get550").With(Reason550.AccessDenied);

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");
        }

        [Test]
        public void TestInvokeBadParameter() {
            Expect.Once.On(MockMessages).Method("Get501");

            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "");
        }

        [Test]
        public void TestInvokeNotLoggedIn() {
            State.User = null;
            Expect.Once.On(MockMessages).Method("Get530");
            PrivateObject.WrappedObject.Invoke(MockFtpServer, State, "a.txt");
        }
    }
}
