/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;
using System.Reflection;
using NUnit.Framework;

namespace OpenServers.Net.FtpServer {
    [TestFixture]
    public class MessagesTest {

        [Test]
        public void TestAllMessages() {
            Messages messages = new Messages();
            MethodInfo[] methods = messages.GetType().GetMethods();
            foreach (MethodInfo method in methods) {
                ParameterInfo[] parameters = method.GetParameters();
                if (parameters.Length == 0) {
                    method.Invoke(messages, null);
                }
            }

            messages.Get550(Reason550.AccessDenied);
            messages.Get550(Reason550.FileAlreadyExists);
            messages.Get550(Reason550.FileNotFound);
            try {
                messages.Get550((Reason550)int.MaxValue);
                Assert.Fail("Should throw exception");
            } catch (Exception) {
                // ok
            }

            messages.Get211(Reason211.End);
            messages.Get211(Reason211.ExtensionsSupported);
            messages.Get211(Reason211.NoFeatures);
            try {
                messages.Get211((Reason211)int.MaxValue);
                Assert.Fail("Should throw exception");
            } catch (Exception) {
                // ok
            }

            messages.Get150("asdf");

            messages.Get257("asdf", Reason257.CurrentDirectory);
            messages.Get257("asdf", Reason257.DirectoryCreated);
            try {
                messages.Get257("asdf", (Reason257)int.MaxValue);
                Assert.Fail("Should throw exception");
            } catch (Exception) {
                // ok
            }

            messages.Get215("asdf");
        }
    }
}
