/*
     Copyright 2007 Joseph M. Ferner

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

namespace OpenServers.Net.HttpServer {
    /// <summary>
    /// Enumeration of possible http response codes.
    /// </summary>
    public enum HttpResponseCode : int {
        /// <summary>
        /// 200 OK
        /// 
        /// The request has succeeded. The information returned with the response is dependent on the method used in the request, for example: 
        /// GET an entity corresponding to the requested resource is sent in the response; 
        /// HEAD the entity-header fields corresponding to the requested resource are sent in the response without any message-body; 
        /// POST an entity describing or containing the result of the action; 
        /// TRACE an entity containing the request message as received by the end server.
        /// </summary>
        SC200 = 200,

        /// <summary>
        /// 400 Bad Request
        /// </summary>
        SC400 = 400,

        /// <summary>
        /// 401 Access Denied
        /// </summary>
        SC401 = 401,

        /// <summary>
        /// 404 File not found
        /// </summary>
        SC404 = 404
    }
}
